package Bundle::QuadPres

$VERSION = '0.8.3';

1;

__END__

=head1 NAME

Bundle::QuadPres - A bundle to install external CPAN modules used by Quad-Pres

=head1 SYNOPSIS

  
Perl one liner using CPAN.pm:

  perl -MCPAN -e 'install Bundle::QuadPres'

Use of CPAN.pm in interactive mode:

  $> perl -MCPAN -e shell
  cpan> install Bundle::QuadPres
  cpan> quit

Just like the manual installation of perl modules, the user may
need root access during this process to insure write permission 
is allowed within the intstallation directory.


=head1 CONTENTS

CGI

Config::IniFiles

Data::Dumper

Error

File::Find

Getopt::Long

MIME::Types

HTML::Links::Localize

=head1 DESCRIPTION

This bundle installs modules needed by Quad-Pres:

http://vipe.technion.ac.il/~shlomif/quadpres/

=head1 AUTHOR

Shlomi Fish E<lt>F<shlomif@vipe.technion.ac.il>E<gt>

=cut




